@@ -5,12 +5,12 @@ use strict;
 use warnings;
 use Tie::IxHash;
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 use Types::Standard qw/Str/;
 use Compiled::Params::OO qw/cpo/;
 use JSON;
 
-our $validate;
+our ($validate, $JSON);
 BEGIN {
 	$validate = cpo(
 		new => {
@@ -40,17 +40,14 @@ BEGIN {
 			}
 		}
 	);
+	$JSON = JSON->new->pretty;
 }
 
-our $JSON = JSON->new->pretty;
-
 sub new {
 	my $class = shift;
 	my $args = $validate->new->(@_);
 	my $self = bless {}, $class;
-	my %order;
-	tie %order, 'Tie::IxHash';
-	$self->{schema} = \%order;
+	$self->{schema} = _tie_hash();
 	$self->{schema}{'$schema'} = $args->schema;
 	$self->{schema}{'$id'} = $args->id;
 	$self->{schema}{title} = $args->title;
@@ -99,17 +96,14 @@ sub _build_props {
 		$self->_unique_examples($props, $data);
 		return if ref $props->{type};
 		if (!$props->{properties}) {
-			my %properties;
-			tie %properties, 'Tie::IxHash';
-			$props->{properties} = \%properties;
+			$props->{required} = {};
+			$props->{properties} = _tie_hash();
 		}
 		for my $key (sort keys %{$data}) {
 			$props->{required}->{$key}++;
 			my $id = $path . '/properties/' . $key;
 			unless ($props->{properties}{$key}) {
-				my %properties;
-				tie %properties, 'Tie::IxHash';
-				$props->{properties}{$key} = \%properties;
+				$props->{properties}{$key} = _tie_hash();
 				$props->{properties}{$key}{'$id'} = $id;
 				$props->{properties}{$key}{title} = 'The ' . ucfirst($key) . ' Schema';
 				$props->{properties}{$key}{description} = 'An explanation about the purpose of this instance.';
@@ -120,9 +114,7 @@ sub _build_props {
 		$self->_add_type($props, 'array');
 		my $id = $path . '/items';
 		unless ($props->{items}) {
-			my %items;
-			tie %items, 'Tie::IxHash';
-			$props->{items} = \%items;
+			$props->{items} = _tie_hash();
 			$props->{items}{'$id'} = $id;
 			$props->{items}{title} = 'The Items Schema';
 			$props->{items}{description} = 'An explanation about the purpose of this instance.';
@@ -153,6 +145,12 @@ sub _build_props {
 	return $props;
 }
 
+sub _tie_hash {
+	my %properties;
+	tie %properties, 'Tie::IxHash';
+	return \%properties;
+}
+
 sub _add_type {
 	my ($self, $props, $type) = @_;
 	if (!$props->{type}) {
@@ -182,7 +180,7 @@ JSON::Schema::Generate - Generate JSON Schemas from data!
 
 =head1 VERSION
 
-Version 0.01
+Version 0.02
 
 =cut
 
